aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/lib/action_controller/scaffolding.rb
diff options
context:
space:
mode:
authorDavid Heinemeier Hansson <david@loudthinking.com>2007-02-20 22:09:12 +0000
committerDavid Heinemeier Hansson <david@loudthinking.com>2007-02-20 22:09:12 +0000
commite1056530665d5c8eed2c325157fbb88553eb2678 (patch)
tree30341bae8b9a63faed289f9dc56c1a654a449731 /actionpack/lib/action_controller/scaffolding.rb
parent89cb34c9cfe9d169b79206b74c602e91bc7116a5 (diff)
downloadrails-e1056530665d5c8eed2c325157fbb88553eb2678.tar.gz
rails-e1056530665d5c8eed2c325157fbb88553eb2678.tar.bz2
rails-e1056530665d5c8eed2c325157fbb88553eb2678.zip
Added .erb and .builder as preferred aliases to the now deprecated .rhtml and .rxml extensions [Chad Fowler]. This is done to separate the renderer from the mime type. .erb templates are often used to render emails, atom, csv, whatever. So labeling them .rhtml doesn't make too much sense. The same goes for .rxml, which can be used to build everything from HTML to Atom to whatever. .rhtml and .rxml will continue to work until Rails 3.0, though. So this is a slow phasing out. All generators and examples will start using the new aliases, though.
git-svn-id: http://svn-commit.rubyonrails.org/rails/trunk@6178 5ecf4fe2-1ee6-0310-87b1-e25e094e27de
Diffstat (limited to 'actionpack/lib/action_controller/scaffolding.rb')
-rw-r--r--actionpack/lib/action_controller/scaffolding.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/actionpack/lib/action_controller/scaffolding.rb b/actionpack/lib/action_controller/scaffolding.rb
index d02a31e6fc..11ece16f0e 100644
--- a/actionpack/lib/action_controller/scaffolding.rb
+++ b/actionpack/lib/action_controller/scaffolding.rb
@@ -71,7 +71,7 @@ module ActionController
# end
# end
#
# The <tt>render_scaffold</tt> method will first check to see if you've made your own template (like "weblog/show.rhtml" for
# the show action) and if not, then render the generic template for that action. This gives you the possibility of using the
# scaffold while you're building your specific application. Start out with a totally generic setup, then replace one template
# and one action at a time while relying on the rest of the scaffolded templates and actions.
@@ -176,7 +176,7 @@ module ActionController
end
def scaffold_path(template_name)
- File.dirname(__FILE__) + "/templates/scaffolds/" + template_name + ".rhtml"
+ File.dirname(__FILE__) + "/templates/scaffolds/" + template_name + ".erb"
end
def caller_method_name(caller)
@@ -71,7 +71,7 @@ module ActionController
# end
#
- # The <tt>render_scaffold</tt> method will first check to see if you've made your own template (like "weblog/show.rhtml" for
+ # The <tt>render_scaffold</tt> method will first check to see if you've made your own template (like "weblog/show.erb" for
# the show action) and if not, then render the generic template for that action. This gives you the possibility of using the
# scaffold while you're building your specific application. Start out with a totally generic setup, then replace one template